@@ -1,4 +1,4 @@
-#' Create a linear patch
+#' Create a linear patch (beta version).
 #'
 #' @description Create a linear patch, setting direction and convolution. The higher the convolution degree, the weaker the
 #' linear shape (and direction).
@@ -17,7 +17,8 @@
 #' library(raster)
 #' r <- matrix(0,33,33)
 #' r <- raster(r, xmn=0, xmx=10, ymn=0, ymx=10)
-#' plot(makeLine(r, size=500, rast=TRUE))
+#' plot(makeLine(r, size=50, spt = 545, direction=45, convol=0.05, rast=TRUE))
+#'
 #' @export
 makeLine <- function(context, size, direction=NULL, convol=0.5, spt=NULL, bgr=0, edge=FALSE, rast=FALSE, val=1) {
   if(!is.matrix(context)) {
@@ -55,7 +56,7 @@ makeLine <- function(context, size, direction=NULL, convol=0.5, spt=NULL, bgr=0,
   while(cg < size){
     ad <- .contigCells(spt, dim1, dim2)
     ad <- ad[.subset(mtx, ad) == bgr]
-    ad <- ad[!is.na(ad)]
+    ad <- ad[is.finite(ad)]
     if(length(ad) == 0) {
       edg <- edg[edg != spt]
       if(length(edg) <= 1) {
@@ -125,7 +126,7 @@ makeLine <- function(context, size, direction=NULL, convol=0.5, spt=NULL, bgr=0,
   while(cg < size){
     ad <- .contigCells(spt, dim1, dim2)
     ad <- ad[.subset(mtx, ad) == bgr]
-    ad <- ad[!is.na(ad)]
+    ad <- ad[is.finite(ad)]
     if(length(ad) == 0) {
       edg <- edg[edg != spt]
       if(length(edg) <= 1) {
