@@ -4,15 +4,15 @@
 #' @param context Raster object or matrix, an empty landscape raster or a mask indicating where the patch cannot be generated (see bgr below).
 #' @param size integer. Size of the patch to be generated, as number of raster cells.
 #' @param spt integer or matrix. The seed point location around which the patch is generated (a random point is given by default). It can be an integer, as index of the cell in the raster, or a two columns matrix indicating x and y coordinates (an integer vector of length 2 is accepted too).
-#' @param bgr integer. Value of background cells, where a patch can be generated (default is zero). Cells/classes which cannot be changed must have a different value.
+#' @param bgr integer. A single value of background cells, where a patch can be generated (default is zero). Cells/classes which cannot be changed must have a different value.
 #' @param edge logical. Should the vector of edge cells of the patch be returned?
 #' @param rast logical. If TRUE returns a Raster object, otherwise a vector of cell numbers where the patch occurs
 #' @param val integer. The value to be assigned to patch cells, when \code{rast=TRUE}
 #' @return A vector of raster cell numbers, or a RasterLayer object if \code{rast=TRUE}. If \code{edge=TRUE} a
 #' list of two vectors is returned: one for the inner raster cells and the second for cells at the edge of the patch.
-#' @details The patch is created starting from the seed point and iteratively sampling randomly neighbouring cells at the edge of the patch.
+#' @details The patch is created starting from the seed point and iteratively sampling randomly neighbouring cells at the edge of the patch, according to von Neumann neighbourhood (four cells, aka Rook case).
 #' There is a tolerance of +/- 3 cells from the patch size declared in \code{size} argument.
-#' Also, argument \code{bgr} accepts a single value only, unlike \code{makeClass} that accept multiple.
+#' Argument \code{bgr} accepts a single value only, unlike \code{makeClass} that accepts multiple and should therefore preferred.
 #' @examples
 #' library(raster)
 #' mtx = matrix(0, 33, 33)
@@ -75,7 +75,7 @@ makePatch <- function(context, size, spt=NULL, bgr=0, edge=FALSE, rast=FALSE, va
     ad <- .contigCells(spt, dim1, dim2)
     ## The following stands for {ad <- bgrCells[which(bgrCells %in% ad)]}. It was {d <- fastmatch::fmatch(ad, bgrCells, nomatch = 0);ad <- bgrCells[d]}
     ad <- ad[.subset(mtx, ad) == bgr] #ad[mtx[ad] == bgr]
-    ad <- ad[!is.na(ad)]
+    ad <- ad[is.finite(ad)]
     if(length(ad) == 0) {
       edg <- edg[edg != spt]
       if(length(edg) <= 1) {
